@@ -51,12 +51,12 @@ def convert_from_env(env: Environment, output_dir: Path):
             resource = object.read()
 
             if isinstance(resource, (Sprite, Texture2D)):
-                target_path = Path(output_dir, env.path, resource.name)
+                target_path = output_dir.joinpath(env.path, resource.name)
                 target_path.parent.mkdir(parents=True, exist_ok=True)
                 resource.image.save(target_path.with_suffix(".png"))
 
             elif isinstance(resource, TextAsset):
-                target_path = Path(output_dir, env.path, resource.name)
+                target_path = output_dir.joinpath(env.path, resource.name)
                 target_path_str = target_path.as_posix()
                 data = bytes(resource.script)
 
@@ -75,11 +75,12 @@ def convert_from_env(env: Environment, output_dir: Path):
                         write_bytes(data, target_path)
             
             elif isinstance(resource, AudioClip):
-                target_path = Path(output_dir, env.path, resource.name)
-                write_bytes(b"".join(resource.samples.values()), target_path.with_suffix(".wav"))
+                target_path = output_dir.joinpath(env.path, resource.name)
+                for audio_name, audio_data in resource.samples.items():
+                    write_bytes(audio_data, target_path.joinpath(audio_name).with_suffix(".wav"))
             
             elif isinstance(resource, MonoBehaviour):
-                target_path = Path(output_dir, env.path, resource.name)
+                target_path = output_dir.joinpath(env.path, resource.name)
                 tree = resource.read_typetree()
                 if not tree["m_Name"] or tree["m_Name"].isspace():
                     target_path = Path(output_dir, str(resource.path_id))
