@@ -3,8 +3,8 @@ from pathlib import Path
 from shutil import rmtree
 from warnings import warn
 import UnityPy
+from PIL import Image
 from .convert_ab import convert_from_env
-from .combine import combine
 
 FilePath = str | PathLike[str]
 
@@ -34,7 +34,17 @@ def convert(input_dir: FilePath, output_dir: FilePath, overwrite: bool = True):
 def combine_textures(input_dir: Path):
     for alpha_path in input_dir.glob("**/*_alpha.png"):
         if (rgb_path := alpha_path.with_name(alpha_path.name[:-10]).with_suffix(".png")).exists():
-            target_path = rgb_path.with_name(
-                rgb_path.name.split("-")[1]
+            target_path = (
+                rgb_path
+                .with_name(rgb_path.name.split("-")[1])
+                .with_suffix(".png")
             )
-            combine(rgb_path, alpha_path, target_path.with_suffix(".png"))
\ No newline at end of file
+
+            rgb_image = Image.open(rgb_path).convert("RGBA")
+            alpha_image = Image.open(alpha_path).convert("L")
+
+            rgb_image.putalpha(alpha_image)
+            rgb_image.save(target_path)
+
+            rgb_path.unlink()
+            alpha_path.unlink()
\ No newline at end of file
